==> kea-docs-2.2.0-3-x86_64.pkg.tar.zst: usr/share/doc/kea/devel/d0/dee/structisc_1_1dhcp_1_1Lease.js <==
var structisc_1_1dhcp_1_1Lease =
[
    [ "Type", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a9257a6a410119ea79f29b9d2756c8769", [
      [ "TYPE_NA", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a9257a6a410119ea79f29b9d2756c8769ad788ece2b98c7fd30e621550be0f7874", null ],
      [ "TYPE_TA", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a9257a6a410119ea79f29b9d2756c8769a277f16fa1c863e5b4369f1a231bbe69e", null ],
      [ "TYPE_PD", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a9257a6a410119ea79f29b9d2756c8769a7850a72f42a993131bb26fc30bb185cd", null ],
      [ "TYPE_V4", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a9257a6a410119ea79f29b9d2756c8769a7c7ef1b8d550e612d7c7d3fa555eea36", null ]
    ] ],
    [ "Lease", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a845e926054d9450625a4c63d29a50eba", null ],
    [ "~Lease", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a16ab38f6d32ab2f40f6738adb183c9aa", null ],
    [ "decline", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a04bc1e66d468b4ee6c8c3af4aefe8cf1", null ],
    [ "expired", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a75c7cb2ccbe062fb09ec08e540b7c80b", null ],
    [ "getExpirationTime", "d0/dee/structisc_1_1dhcp_1_1Lease.html#aab763ed025872c92d0de61621a17867e", null ],
    [ "getHWAddrVector", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a5e9372ba7046678ae8ac9ddc7717c534", null ],
    [ "getType", "d0/dee/structisc_1_1dhcp_1_1Lease.html#aaab301bb3184cb3f3ab80e4cb75ba471", null ],
    [ "hasIdenticalFqdn", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a04b7faaec03f9e0c794926913fb52775", null ],
    [ "stateDeclined", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a38e59c2e67d4a728661907f4e5f757b2", null ],
    [ "stateExpiredReclaimed", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a4097c25aa1d7c75aa2349070d8fc264a", null ],
    [ "toText", "d0/dee/structisc_1_1dhcp_1_1Lease.html#ad044eebf0821b50a18f09fd446c4ba4d", null ],
    [ "updateCurrentExpirationTime", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a0451d02906f031a7c16208f5cc829606", null ],
    [ "addr_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#afddac8c9e324e9126d7a977ced4f069e", null ],
    [ "cltt_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#ac71dc7f97dd753096a0f448c6649cdcf", null ],
    [ "current_cltt_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#afe4f8931448df98d3b00bcacbc84a5bb", null ],
    [ "current_valid_lft_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a4fefd6cf1a90dd5df42a8cfdb7f9ac54", null ],
    [ "fqdn_fwd_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#aba1608dc956d2b94cbb3ef332653e4e7", null ],
    [ "fqdn_rev_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#af07cd1f5617e351228d42de98c209bd5", null ],
    [ "hostname_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a9ebed6450bde6bda6e2fdd5aec8b62e1", null ],
    [ "hwaddr_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#ae882d35e1e154603fbace66931c80d76", null ],
    [ "reuseable_valid_lft_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a186a3ac4b81274d52d5aecb96db2c7a9", null ],
    [ "state_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#aa935911deaa4b7e1deec42473ef78f37", null ],
    [ "subnet_id_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a536f1480c88b0633f41e07e582a5ea7f", null ],
    [ "valid_lft_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a615302a9140991942225b9809ddd50fb", null ]
];

==> kea-docs-2.6.2-1-x86_64.pkg.tar.zst: usr/share/doc/kea/devel/d0/dee/structisc_1_1dhcp_1_1Lease.js <==
var structisc_1_1dhcp_1_1Lease =
[
    [ "Type", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a9257a6a410119ea79f29b9d2756c8769", [
      [ "TYPE_NA", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a9257a6a410119ea79f29b9d2756c8769ad788ece2b98c7fd30e621550be0f7874", null ],
      [ "TYPE_TA", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a9257a6a410119ea79f29b9d2756c8769a277f16fa1c863e5b4369f1a231bbe69e", null ],
      [ "TYPE_PD", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a9257a6a410119ea79f29b9d2756c8769a7850a72f42a993131bb26fc30bb185cd", null ],
      [ "TYPE_V4", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a9257a6a410119ea79f29b9d2756c8769a7c7ef1b8d550e612d7c7d3fa555eea36", null ]
    ] ],
    [ "Lease", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a845e926054d9450625a4c63d29a50eba", null ],
    [ "~Lease", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a16ab38f6d32ab2f40f6738adb183c9aa", null ],
    [ "decline", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a04bc1e66d468b4ee6c8c3af4aefe8cf1", null ],
    [ "expired", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a75c7cb2ccbe062fb09ec08e540b7c80b", null ],
    [ "getExpirationTime", "d0/dee/structisc_1_1dhcp_1_1Lease.html#aab763ed025872c92d0de61621a17867e", null ],
    [ "getHWAddrVector", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a5e9372ba7046678ae8ac9ddc7717c534", null ],
    [ "getType", "d0/dee/structisc_1_1dhcp_1_1Lease.html#aaab301bb3184cb3f3ab80e4cb75ba471", null ],
    [ "hasIdenticalFqdn", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a04b7faaec03f9e0c794926913fb52775", null ],
    [ "stateDeclined", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a38e59c2e67d4a728661907f4e5f757b2", null ],
    [ "stateExpiredReclaimed", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a4097c25aa1d7c75aa2349070d8fc264a", null ],
    [ "toElement", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a358cd4ac750836ac75ab6481e90ba57f", null ],
    [ "toText", "d0/dee/structisc_1_1dhcp_1_1Lease.html#ad044eebf0821b50a18f09fd446c4ba4d", null ],
    [ "updateCurrentExpirationTime", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a0451d02906f031a7c16208f5cc829606", null ],
    [ "addr_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#afddac8c9e324e9126d7a977ced4f069e", null ],
    [ "cltt_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#ac71dc7f97dd753096a0f448c6649cdcf", null ],
    [ "current_cltt_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#afe4f8931448df98d3b00bcacbc84a5bb", null ],
    [ "current_valid_lft_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a4fefd6cf1a90dd5df42a8cfdb7f9ac54", null ],
    [ "fqdn_fwd_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#aba1608dc956d2b94cbb3ef332653e4e7", null ],
    [ "fqdn_rev_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#af07cd1f5617e351228d42de98c209bd5", null ],
    [ "hostname_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a9ebed6450bde6bda6e2fdd5aec8b62e1", null ],
    [ "hwaddr_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#ae882d35e1e154603fbace66931c80d76", null ],
    [ "pool_id_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a56db3a29c1475d9c6ada3c10b1f3c95c", null ],
    [ "reuseable_valid_lft_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a186a3ac4b81274d52d5aecb96db2c7a9", null ],
    [ "state_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#aa935911deaa4b7e1deec42473ef78f37", null ],
    [ "subnet_id_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a536f1480c88b0633f41e07e582a5ea7f", null ],
    [ "valid_lft_", "d0/dee/structisc_1_1dhcp_1_1Lease.html#a615302a9140991942225b9809ddd50fb", null ]
];
